use strict;
use warnings;
use Test::More;
use UUID ();


UUID::generate(my $bin);
ok 1, 'generate';

ok !UUID::is_null($bin), 'not null';

UUID::clear($bin);
ok 1, 'clear';

ok UUID::is_null($bin), 'is null';

done_testing;
