use warnings;
use Test::More tests => 1;
use UUID ();


#... uuid.h ...
#define UUID_VARIANT_NCS  0
#define UUID_VARIANT_DCE  1
#define UUID_VARIANT_MICROSOFT  2
#define UUID_VARIANT_OTHER  3

UUID::generate_time(my $bin);
is UUID::variant($bin), 1, 'UUID variant';

done_testing;
