use strict;
use warnings;
use Test::More;
use UUID ();


UUID::generate_time(my $bin1);
ok 1, 'generate 1';
UUID::generate_time(my $bin2);
ok 1, 'generate 2';

ok UUID::compare($bin1,$bin2), 'compare different';

$bin1 = $bin2;

ok !UUID::compare($bin1,$bin2), 'compare same';

done_testing;
